┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/klistview_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/klistview_p.h')
-rw-r--r--src/klistview_p.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/klistview_p.h b/src/klistview_p.h
index b590b2307..4d0cec138 100644
--- a/src/klistview_p.h
+++ b/src/klistview_p.h
@@ -85,10 +85,12 @@ public:
QRect categoryVisualRect(const QString &category);
/**
* This method will draw a new category with name @p category on the rect
* specified by @p option.rect, with painter @p painter
*/
- void drawNewCategory(const QString &category,
+ void drawNewCategory(const QModelIndex &index,
+ int sortRole,
const QStyleOption &option,
QPainter *painter);
@@ -131,6 +133,8 @@ public:
QPoint initialPressPosition;
QPoint mousePosition;
QItemSelection lastSelection;
+ QModelIndex currentViewIndex;
+ int forcedSelectionPosition;
// Cache data
// We cannot merge some of them into structs because it would affect
@@ -138,6 +142,7 @@ public:
QHash<QModelIndex, struct ElementInfo> elementsInfo; // in source model
QHash<QModelIndex, QRect> elementsPosition; // in source model
QHash<QModelIndex, QModelIndex> elementDictionary; // mapped indexes
+ QHash<QModelIndex, QModelIndex> invertedElementDictionary; // mapped indexes
QHash<QString, QModelIndexList> categoriesIndexes;
QHash<QString, QRect> categoriesPosition;
QStringList categories;
@@ -85,10 +85,12 @@ public:
QRect categoryVisualRect(const QString &category);
/**
- * This method will draw a new category with name @p category on the rect
- * specified by @p option.rect, with painter @p painter
+ * This method will draw a new category represented by index
+ * @param index on the rect specified by @p option.rect, with
+ * painter @p painter
*/